%define date    20220520

%define major   1
%define minor   0
%define soname  %{major}.%{minor}
%define libname %mklibname %{name} %{soname}
%define devname %mklibname %{name} -d

Name:           poly2tri
Version:        1.0
Release:        %mkrel -c %{date} 1
Summary:        A 2D constrained Delaunay triangulation library
License:        BSD
Group:          Development/Other
URL:            https://github.com/jhasse/poly2tri
Source0:        %{name}-%{date}.tar.xz
Patch0:		poly2tri-build-fix.patch
BuildRequires:	cmake
BuildRequires:	ninja
BuildRequires:	boost-devel
BuildRequires:  GL-devel
BuildRequires:	glfw-devel

%description
Library based on the paper "Sweep-line algorithm for constrained Delaunay
triangulation" by V. Domiter and and B. Zalik.

%package -n     %{libname}
Summary:        A 2D constrained Delaunay triangulation library
Group:          System/Libraries
Obsoletes:      %{name} < 0.0-0.20130501hg26242d0aa7b8.2
Obsoletes:      %{name}-%{libname} < 0.0-0.20130501hg26242d0aa7b8.3

%description -n %{libname}
Library based on the paper "Sweep-line algorithm for constrained Delaunay
triangulation" by V. Domiter and and B. Zalik.

%package -n     %{devname}
Summary:        Development files for %{name}
Group:          Development/Other
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Obsoletes:      %{name}-devel < 0.0-0.20130501hg26242d0aa7b8.2
Obsoletes:      %{name}-%{devname} < 0.0-0.20130501hg26242d0aa7b8.3

%description -n %{devname}
Development files for %{name}.

%package examples
Summary:	Example files for %{name}

%description examples
This package contains testbed and example files for %{name}.

%prep
%setup -q -n %{name}-%{date}
%autopatch -p1

iconv -f iso8859-1 -t utf-8 AUTHORS > AUTHORS.conv && \
touch -r AUTHORS AUTHORS.conv && \
mv AUTHORS.conv AUTHORS

# update paths for examples
sed -i \
  -e 's,build/testbed/p2t,%{_bindir}/p2t,g' \
  -e 's,testbed/data/,%{_datadir}/doc/%{name}/examples/,g' \
  README.md

%build
%cmake -GNinja \
  -DP2T_BUILD_TESTS=ON \
  -DP2T_BUILD_TESTBED=ON \
  -DCMAKE_SKIP_INSTALL_RPATH=ON
%cmake_build

%install
%cmake_install

# examples
mkdir -p %{buildroot}%{_datadir}/doc/%{name}/examples
install -Dpm644 testbed/data/*.dat %{buildroot}%{_datadir}/doc/%{name}/examples/
install -Dpm644 README.md %{buildroot}%{_datadir}/doc/%{name}/

# Add a pkgconfig entry
cat > %{name}.pc << EOF
prefix=%{_prefix}
libdir=%{_libdir}
includedir=%{_includedir}

Name: %{name}
Description: A 2D constrained Delaunay triangulation library
Version: 1.0-%{date}

Requires:
Libs: -L\${libdir} -l%{name}
Cflags: -I\${includedir}/%{name}
EOF
install -D -m644 %{name}.pc %{buildroot}%{_libdir}/pkgconfig/%{name}.pc

%check
%ctest

%files -n %{libname}
%license LICENSE
%doc AUTHORS README.md
%{_libdir}/lib%{name}.so.%{major}{,.*}

%files -n %{devname}
%{_includedir}/%{name}
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/%{name}.pc

%files examples
%docdir %{_datadir}/doc/%{name}/
%doc %{_datadir}/doc/%{name}/*
%{_bindir}/p2t


%changelog
* Sat May 21 2022 wally <wally> 1.0-0.20220520.1.mga9
+ Revision: 1859672
- new snapshot 20220520
- switch to cmake build
- add examples pkg for testbed (p2t and example files)

* Sun Mar 27 2022 umeabot <umeabot> 1.0-0.20160413.4.mga9
+ Revision: 1829057
- Mageia 9 Mass Rebuild

* Fri Feb 14 2020 umeabot <umeabot> 1.0-0.20160413.3.mga8
+ Revision: 1516121
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%setup_compile_flags

* Sun Sep 23 2018 umeabot <umeabot> 1.0-0.20160413.2.mga7
+ Revision: 1300340
- Mageia 7 Mass Rebuild

* Sun Apr 24 2016 akien <akien> 1.0-0.20160413.1.mga6
+ Revision: 1005865
- Dev snapshot from new upstream fork

* Mon Feb 08 2016 umeabot <umeabot> 1.0-0.20130501.7.mga6
+ Revision: 944405
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 1.0-0.20130501.6.mga5
+ Revision: 751010
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.0-0.20130501.5.mga5
+ Revision: 687716
- Mageia 5 Mass Rebuild

* Sat Jun 14 2014 akien <akien> 1.0-0.20130501.4.mga5
+ Revision: 636069
- Fix description in pkg-config file, %%summary referenced the -devel summary

* Wed Jun 11 2014 akien <akien> 1.0-0.20130501.3.mga5
+ Revision: 635621
- Fix hardcoded paths and escape variables in pkgconfig entry

* Wed Jun 11 2014 akien <akien> 1.0-0.20130501.2.mga5
+ Revision: 635559
- Add pkgconfig entry

* Tue Jun 10 2014 akien <akien> 1.0-0.20130501.1.mga5
+ Revision: 635528
- Base the package version on the soname (1.0)

* Tue Jun 10 2014 akien <akien> 0.0-0.20130501hg26242d0aa7b8.3.mga5
+ Revision: 635435
- Fix subpackage naming mistake

* Tue Jun 10 2014 akien <akien> 0.0-0.20130501hg26242d0aa7b8.2.mga5
+ Revision: 635299
- Rename packages to comply with Mageia's library policy

* Thu Jun 05 2014 spuhler <spuhler> 0.0-0.20130501hg26242d0aa7b8.1.mga5
+ Revision: 633558
- changed the snapshot date
- upgrade to poly2tri-26242d0aa7b8

* Thu Jun 05 2014 spuhler <spuhler> 0.0-0.20120407hgacf81f1f1764.1.mga5
+ Revision: 633542
- first release after import from Fedora
- imported package poly2tri

